==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/de.js <==
﻿/*
 * PLUGIN RSS
 *
 * German language file.
 *
 * Author: Dario Rugani (kontakt@rugani.de)
 */

 theUILang.addRSS			= "RSS Feed hinzufügen";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Alias";
 theUILang.rssAuto			= "Dateien im Feed werden automatisch heruntergeladen";
 theUILang.allFeeds			= "Alle Feeds";
 theUILang.incorrectURL 		= "Bitte gebe die korrekte Feed-URL an."
 theUILang.cantFetchRSS 		= "Fehler beim Laden des Feeds.";
 theUILang.rssAlreadyExist		= "Feed bereits vorhanden.";
 theUILang.rssDontExist 		= "Feed nicht vorhanden.";
 theUILang.rssCantLoadTorrent		= "Fehler beim Laden vom Torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Bereits geladen";
 theUILang.rssMenuLoad			= "Downloaden";
 theUILang.rssMenuOpen			= "Im Browser öffenen";
 theUILang.rssMenuClearHistory		= "History leeren";
 theUILang.rssMenuAddToFilter		= "Zu Favoriten hinzufügen";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Update Feed";
 theUILang.rssMenuDisable		= "Feed deaktivieren";
 theUILang.rssMenuEnable		= "Feed aktivieren";
 theUILang.rssMenuEdit			= "Feed bearbeiten";
 theUILang.rssMenuDelete		= "Feed löschen";
 theUILang.rssDeletePrompt		= "Ausgewählten Feed(s) wirklich löschen?";
 theUILang.rssNewFilter 		= "Neuer Filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter 		= "Hinzufügen";
 theUILang.rssDelFilter 		= "Löschen";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filtereinstellungen";
 theUILang.rssIncorrectFilter		= "Filter ist falsch.";
 theUILang.foundedByFilter		= "Übereinstimmen";
 theUILang.rssExclude			= "Ausschließen";
 theUILang.rssStatusError		= "Fehler beim Laden";
 theUILang.rssFeeds			= "Feeds";
 theUILang.rssCheckTitle		= "Überprüfe Titelfeld";
 theUILang.rssCheckDescription		= "Überprüfe Beschreibungsfeld";
 theUILang.rssCheckLink 		= "Überprüfe Linkfeld";
 theUILang.rssMinInterval		= "Min. Interval";
 theUILang.rssIntervalAlways		= "(Immer übereinstimmen)";
 theUILang.rssIntervalOnce		= "(Einmal übereinstimmen)";
 theUILang.rssInterval12h		= "12 Stunden";
 theUILang.rssInterval1d		= "1 Tag";
 theUILang.rssInterval2d		= "2 Tage";
 theUILang.rssInterval3d		= "3 Tage";
 theUILang.rssInterval4d		= "4 Tage";
 theUILang.rssInterval6d		= "6 Tage";
 theUILang.rssInterval1w		= "1 Woche";
 theUILang.rssInterval2w		= "2 Wochen";
 theUILang.rssInterval3w		= "3 Wochen";
 theUILang.rssInterval1m		= "1 Monat";
 theUILang.rssClearFilter		= "Reset";
 theUILang.rssMarkAs			= "Mark as";
 theUILang.rssAsLoaded			= "Geladen";
 theUILang.rssAsUnloaded		= "Nicht geladen";
 theUILang.addRSSGroup			= "RSS Gruppe hinuzfügen";
 theUILang.editRSSGroup 		= "RSS Gruppe bearbeiten";
 theUILang.addRSSGroupContent		= "Inhalt";
 theUILang.rssMenuGroupDisable		= "Gruppe deaktivieren";
 theUILang.rssMenuGroupRefresh		= "Gruppe aktualisieren";
 theUILang.rssMenuGroupEnable		= "Gruppe aktivieren";
 theUILang.rssMenuGroupEdit		= "Gruppe bearbeiten";
 theUILang.rssMenuGroupDelete		= "Gruppe löschen";
 theUILang.rssMenuGroupContentsDelete	= "Inhalt löschen";
 theUILang.rssDeleteGroupPrompt 	= "Ausgewählte Gruppe wirklich löschen?";
 theUILang.rssDeleteGroupContentsPrompt = "Ausgewählte Gruppe wirklich mit allen Inhalten löschen?";
 theUILang.rssAllFiters 		= "Alle Filter";
 theUILang.rssUpdateInterval 		= "Aktualisierungsintervall";
 theUILang.Directories			= "Verzeichnisse";
 theUILang.Labels			= "Labels";

thePlugins.get("rss").langLoaded();

==> rutorrent-4.3.5.tar.gz: ruTorrent-4.3.5/plugins/rss/lang/de.js <==
﻿/*
 * PLUGIN RSS
 *
 * German language file.
 *
 * Author: Dario Rugani (kontakt@rugani.de)
 */

 theUILang.addRSS			= "RSS Feed hinzufügen";
 theUILang.feedURL			= "Feed URL";
 theUILang.alias			= "Alias";
 theUILang.rssAuto			= "Dateien im Feed werden automatisch heruntergeladen";
 theUILang.allFeeds			= "Alle Feeds";
 theUILang.incorrectURL			= "Bitte gebe die korrekte Feed-URL an.";
 theUILang.cantFetchRSS			= "Fehler beim Laden des Feeds.";
 theUILang.rssAlreadyExist		= "Feed bereits vorhanden.";
 theUILang.rssDontExist			= "Feed nicht vorhanden.";
 theUILang.rssCantLoadTorrent		= "Fehler beim Laden vom Torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Bereits geladen";
 theUILang.rssMenuLoad			= "Downloaden";
 theUILang.rssMenuOpen			= "Im Browser öffenen";
 theUILang.rssMenuClearHistory		= "History leeren";
 theUILang.rssMenuAddToFilter		= "Zu Favoriten hinzufügen";
 theUILang.rssMenuManager		= "RSS Manager";
 theUILang.rssMenuRefresh		= "Update Feed";
 theUILang.rssMenuDisable		= "Feed deaktivieren";
 theUILang.rssMenuEnable		= "Feed aktivieren";
 theUILang.rssMenuEdit			= "Feed bearbeiten";
 theUILang.rssMenuDelete		= "Feed löschen";
 theUILang.rssDeletePrompt		= "Ausgewählten Feed(s) wirklich löschen?";
 theUILang.rssNewFilter			= "Neuer Filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter			= "Hinzufügen";
 theUILang.rssDelFilter			= "Löschen";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filtereinstellungen";
 theUILang.rssIncorrectFilter		= "Filter ist falsch.";
 theUILang.foundedByFilter		= "Übereinstimmen";
 theUILang.rssExclude			= "Ausschließen";
 theUILang.rssStatusError		= "Fehler beim Laden";
 theUILang.rssFeeds			= "Feeds";
 theUILang.rssCheckTitle		= "Überprüfe Titelfeld";
 theUILang.rssCheckDescription		= "Überprüfe Beschreibungsfeld";
 theUILang.rssCheckLink			= "Überprüfe Linkfeld";
 theUILang.rssMinInterval		= "Min. Interval";
 theUILang.rssIntervalAlways		= "(Immer übereinstimmen)";
 theUILang.rssIntervalOnce		= "(Einmal übereinstimmen)";
 theUILang.rssInterval12h		= "12 Stunden";
 theUILang.rssInterval1d		= "1 Tag";
 theUILang.rssInterval2d		= "2 Tage";
 theUILang.rssInterval3d		= "3 Tage";
 theUILang.rssInterval4d		= "4 Tage";
 theUILang.rssInterval6d		= "6 Tage";
 theUILang.rssInterval1w		= "1 Woche";
 theUILang.rssInterval2w		= "2 Wochen";
 theUILang.rssInterval3w		= "3 Wochen";
 theUILang.rssInterval1m		= "1 Monat";
 theUILang.rssClearFilter		= "Reset";
 theUILang.rssMarkAs			= "Mark as";
 theUILang.rssAsLoaded			= "Geladen";
 theUILang.rssAsUnloaded		= "Nicht geladen";
 theUILang.addRSSGroup			= "RSS Gruppe hinuzfügen";
 theUILang.editRSSGroup			= "RSS Gruppe bearbeiten";
 theUILang.addRSSGroupContent		= "Inhalt";
 theUILang.rssMenuGroupDisable		= "Gruppe deaktivieren";
 theUILang.rssMenuGroupRefresh		= "Gruppe aktualisieren";
 theUILang.rssMenuGroupEnable		= "Gruppe aktivieren";
 theUILang.rssMenuGroupEdit		= "Gruppe bearbeiten";
 theUILang.rssMenuGroupDelete		= "Gruppe löschen";
 theUILang.rssMenuGroupContentsDelete	= "Inhalt löschen";
 theUILang.rssDeleteGroupPrompt		= "Ausgewählte Gruppe wirklich löschen?";
 theUILang.rssDeleteGroupContentsPrompt	= "Ausgewählte Gruppe wirklich mit allen Inhalten löschen?";
 theUILang.rssAllFiters			= "Alle Filter";
 theUILang.rssUpdateInterval		= "Aktualisierungsintervall";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Verzeichnisse";
 theUILang.Labels			= "Labels";

thePlugins.get("rss").langLoaded();
